
VER_NT_WORKSTATION = 0x0000001
VER_NT_DOMAIN_CONTROLLER = 0x0000002
VER_NT_SERVER = 0x0000003
VER_SERVER_NT = 0x80000000
VER_WORKSTATION_NT = 0x40000000
VER_SUITE_SMALLBUSINESS = 0x00000001
VER_SUITE_ENTERPRISE = 0x00000002
VER_SUITE_BACKOFFICE = 0x00000004
VER_SUITE_COMMUNICATIONS = 0x00000008
VER_SUITE_TERMINAL = 0x00000010
VER_SUITE_SMALLBUSINESS_RESTRICTED = 0x00000020
VER_SUITE_EMBEDDEDNT = 0x00000040
VER_SUITE_DATACENTER = 0x00000080
VER_SUITE_SINGLEUSERTS = 0x00000100
VER_SUITE_PERSONAL = 0x00000200
VER_SUITE_BLADE = 0x00000400
VER_SUITE_EMBEDDED_RESTRICTED = 0x00000800
VER_SUITE_SECURITY_APPLIANCE = 0x00001000
VER_SUITE_STORAGE_SERVER = 0x00002000
VER_SUITE_COMPUTE_SERVER = 0x00004000
VER_SUITE_WH_SERVER = 0x00008000

PROCESSOR_ARCHITECTURE_AMD64 = 9
PROCESSOR_ARCHITECTURE_IA64 = 6
PROCESSOR_ARCHITECTURE_INTEL = 0
PROCESSOR_ARCHITECTURE_UNKNOWN = 0xffff

PRODUCT_BUSINESS = 0x00000006
PRODUCT_BUSINESS_N = 0x00000010
PRODUCT_CLUSTER_SERVER = 0x00000012
PRODUCT_DATACENTER_SERVER = 0x00000008
PRODUCT_DATACENTER_SERVER_CORE = 0x0000000C
PRODUCT_DATACENTER_SERVER_CORE_V = 0x00000027
PRODUCT_DATACENTER_SERVER_V = 0x00000025
PRODUCT_ENTERPRISE = 0x00000004
PRODUCT_ENTERPRISE_E = 0x00000046
PRODUCT_ENTERPRISE_N = 0x0000001B
PRODUCT_ENTERPRISE_SERVER = 0x0000000A
PRODUCT_ENTERPRISE_SERVER_CORE = 0x0000000E
PRODUCT_ENTERPRISE_SERVER_CORE_V = 0x00000029
PRODUCT_ENTERPRISE_SERVER_IA64 = 0x0000000F
PRODUCT_ENTERPRISE_SERVER_V = 0x00000026
PRODUCT_HOME_BASIC = 0x00000002
PRODUCT_HOME_BASIC_E = 0x00000043
PRODUCT_HOME_BASIC_N = 0x00000005
PRODUCT_HOME_PREMIUM = 0x00000003
PRODUCT_HOME_PREMIUM_E = 0x00000044
PRODUCT_HOME_PREMIUM_N = 0x0000001A
PRODUCT_HYPERV = 0x0000002A
PRODUCT_MEDIUMBUSINESS_SERVER_MANAGEMENT = 0x0000001E
PRODUCT_MEDIUMBUSINESS_SERVER_MESSAGING = 0x00000020
PRODUCT_MEDIUMBUSINESS_SERVER_SECURITY = 0x0000001F
PRODUCT_PROFESSIONAL = 0x00000030
PRODUCT_PROFESSIONAL_E = 0x00000045
PRODUCT_PROFESSIONAL_N = 0x00000031
PRODUCT_SERVER_FOR_SMALLBUSINESS = 0x00000018
PRODUCT_SERVER_FOR_SMALLBUSINESS_V = 0x00000023
PRODUCT_SERVER_FOUNDATION = 0x00000021
PRODUCT_SMALLBUSINESS_SERVER = 0x00000009
PRODUCT_STANDARD_SERVER = 0x00000007
PRODUCT_STANDARD_SERVER_CORE = 0x0000000D
PRODUCT_STANDARD_SERVER_CORE_V = 0x00000028
PRODUCT_STANDARD_SERVER_V = 0x00000024
PRODUCT_STARTER = 0x0000000B
PRODUCT_STARTER_E = 0x00000042
PRODUCT_STARTER_N = 0x0000002F
PRODUCT_STORAGE_ENTERPRISE_SERVER = 0x00000017
PRODUCT_STORAGE_EXPRESS_SERVER = 0x00000014
PRODUCT_STORAGE_STANDARD_SERVER = 0x00000015
PRODUCT_STORAGE_WORKGROUP_SERVER = 0x00000016
PRODUCT_UNDEFINED = 0x00000000
PRODUCT_ULTIMATE = 0x00000001
PRODUCT_ULTIMATE_E = 0x00000047
PRODUCT_ULTIMATE_N = 0x0000001C
PRODUCT_WEB_SERVER = 0x00000011
PRODUCT_WEB_SERVER_CORE = 0x0000001D

PRODUCT_SUITE_BUSINESS = [PRODUCT_BUSINESS, PRODUCT_BUSINESS_N]
PRODUCT_SUITE_CLUSTER = [PRODUCT_CLUSTER_SERVER]
PRODUCT_SUITE_DATACENTER = [PRODUCT_DATACENTER_SERVER, PRODUCT_DATACENTER_SERVER_CORE, \
                            PRODUCT_DATACENTER_SERVER_CORE_V, PRODUCT_DATACENTER_SERVER_V]
PRODUCT_SUITE_ENTERPRISE = [PRODUCT_ENTERPRISE, PRODUCT_ENTERPRISE_E, PRODUCT_ENTERPRISE_N, \
                            PRODUCT_ENTERPRISE_SERVER, PRODUCT_ENTERPRISE_SERVER_CORE, \
                            PRODUCT_ENTERPRISE_SERVER_CORE_V, PRODUCT_ENTERPRISE_SERVER_IA64, \
                            PRODUCT_ENTERPRISE_SERVER_V]
PRODUCT_SUITE_HOME_BASIC = [PRODUCT_HOME_BASIC, PRODUCT_HOME_BASIC_E, PRODUCT_HOME_BASIC_N]
PRODUCT_SUITE_HOME_PREMIUM = [PRODUCT_HOME_PREMIUM, PRODUCT_HOME_BASIC_E, PRODUCT_HOME_PREMIUM_N]
PRODUCT_SUITE_SMALL_BUSINESS = [PRODUCT_MEDIUMBUSINESS_SERVER_MANAGEMENT, \
                                PRODUCT_MEDIUMBUSINESS_SERVER_MESSAGING, \
                                PRODUCT_MEDIUMBUSINESS_SERVER_SECURITY, \
                                PRODUCT_SMALLBUSINESS_SERVER, PRODUCT_SERVER_FOR_SMALLBUSINESS, \
                                PRODUCT_SERVER_FOR_SMALLBUSINESS_V]
PRODUCT_SUITE_PROFESSIONAL = [PRODUCT_PROFESSIONAL, PRODUCT_PROFESSIONAL_E, PRODUCT_PROFESSIONAL_N]
PRODUCT_SUITE_STANDARD = [PRODUCT_STANDARD_SERVER, PRODUCT_STANDARD_SERVER_CORE, \
                          PRODUCT_STANDARD_SERVER_CORE_V, PRODUCT_STANDARD_SERVER_V]
PRODUCT_SUITE_STARTER = [PRODUCT_STARTER, PRODUCT_STARTER_E, PRODUCT_STARTER_N]
PRODUCT_SUITE_STORAGE = [PRODUCT_STORAGE_ENTERPRISE_SERVER, PRODUCT_STORAGE_EXPRESS_SERVER, \
                         PRODUCT_STORAGE_STANDARD_SERVER, PRODUCT_STORAGE_WORKGROUP_SERVER]
PRODUCT_SUITE_ULTIMATE = [PRODUCT_ULTIMATE, PRODUCT_ULTIMATE_E, PRODUCT_ULTIMATE_N]
PRODUCT_SUITE_WEB = [PRODUCT_WEB_SERVER, PRODUCT_WEB_SERVER_CORE]

SERVER_CORE = [PRODUCT_DATACENTER_SERVER_CORE, PRODUCT_DATACENTER_SERVER_CORE_V, \
               PRODUCT_ENTERPRISE_SERVER_CORE, PRODUCT_ENTERPRISE_SERVER_CORE_V, \
               PRODUCT_STANDARD_SERVER_CORE, PRODUCT_STANDARD_SERVER_CORE_V, \
               PRODUCT_WEB_SERVER_CORE]

HYPER_V = [PRODUCT_DATACENTER_SERVER_CORE_V, PRODUCT_DATACENTER_SERVER_V, \
           PRODUCT_ENTERPRISE_SERVER_CORE_V, PRODUCT_ENTERPRISE_SERVER_V, \
           PRODUCT_SERVER_FOR_SMALLBUSINESS_V, PRODUCT_STANDARD_SERVER_CORE_V, \
           PRODUCT_STANDARD_SERVER_V, PRODUCT_STANDARD_SERVER_CORE_V, \
           PRODUCT_STANDARD_SERVER_V]
